@@ -43,6 +43,7 @@ package UMLS::Similarity::res;
 use strict;
 use warnings;
 use UMLS::Similarity;
+use UMLS::Similarity::ErrorHandler;
 
 use vars qw($VERSION);
 $VERSION = '0.07';
@@ -126,34 +127,29 @@ relatednessof concepts in the Unified Medical Language System
 
 =head1 SYNOPSIS
 
-  use UMLS::Interface;
+  #!/usr/bin/perl
 
+  use UMLS::Interface;
   use UMLS::Similarity::res;
 
   my $icpropagation = "samples/icpropagation";
-
-  my %option_hash = ();
+  my %option_hash   = ();
 
   $option_hash{"icpropagation"} = $icpropagation;
 
   my $umls = UMLS::Interface->new(\%option_hash); 
-
   die "Unable to create UMLS::Interface object.\n" if(!$umls);
 
   my $res = UMLS::Similarity::res->new($umls);
-
   die "Unable to create measure object.\n" if(!$res);
 
   my $cui1 = "C0005767";
-
   my $cui2 = "C0007634";
 
   @ts1 = $umls->getTermList($cui1);
-
   my $term1 = pop @ts1;
 
   @ts2 = $umls->getTermList($cui2);
-
   my $term2 = pop @ts2;
 
   my $value = $res->getRelatedness($cui1, $cui2);
